var NAVTREEINDEX1 =
{
"group__PMP__geometric__repair__grp.html#ga91c02ef57e638faf2622eae93e7a25e2":[1,0,10,3],
"group__PMP__hole__filling__grp.html":[1,0,2],
"group__PMP__hole__filling__grp.html#ga18eac756a8f8e5d5f73e645fd4e26cad":[1,0,2,7],
"group__PMP__hole__filling__grp.html#ga3294d97ef095a5ac3b52bc4f0c2c214c":[1,0,2,5],
"group__PMP__hole__filling__grp.html#ga3abdf2d0558822e85f060966b69cae98":[1,0,2,3],
"group__PMP__hole__filling__grp.html#ga8d1d144e74cd9a60e0c8a2ab9f39b7fb":[1,0,2,2],
"group__PMP__hole__filling__grp.html#ga9868fac4d9dca77462ad7828bc99d8a1":[1,0,2,1],
"group__PMP__hole__filling__grp.html#gac1054e734715493e32e78d65fc1f0baf":[1,0,2,6],
"group__PMP__hole__filling__grp.html#gad2d3c43bce0ef90a16530478196d7f42":[1,0,2,4],
"group__PMP__hole__filling__grp.html#gae594ae7862ab6f5f9a06755500fb93fe":[1,0,2,8],
"group__PMP__intersection__grp.html":[1,0,8],
"group__PMP__intersection__grp.html#ga10428990783d0fc500bb1be8e5d10a42":[1,0,8,5],
"group__PMP__intersection__grp.html#ga1c5fee17bd0d92d5a2fba77ed94d4b4d":[1,0,8,11],
"group__PMP__intersection__grp.html#ga1d563c139d9803ed0211f9828805d881":[1,0,8,2],
"group__PMP__intersection__grp.html#ga202575b5d28a41b7246e60e1be95a1ae":[1,0,8,0],
"group__PMP__intersection__grp.html#ga28affb9bdf1b38765479609084cd1e94":[1,0,8,6],
"group__PMP__intersection__grp.html#ga2cb4019111658999234b3e377e3eabcd":[1,0,8,1],
"group__PMP__intersection__grp.html#ga362b69dbf22a03e5a852e5b2efe47e12":[1,0,8,4],
"group__PMP__intersection__grp.html#ga4909920dc48b8285e69feb845feb1e53":[1,0,8,7],
"group__PMP__intersection__grp.html#ga5c8f1c1aba66b32be12d88f852f87fb0":[1,0,8,9],
"group__PMP__intersection__grp.html#ga6c5bed399d14ddbba820ce50d3145712":[1,0,8,10],
"group__PMP__intersection__grp.html#gaea4f28410f96a748e21db75c884224e3":[1,0,8,3],
"group__PMP__intersection__grp.html#gaf0a7348487c7bf93dced127d82afc918":[1,0,8,8],
"group__PMP__keep__connected__components__grp.html":[1,0,1],
"group__PMP__keep__connected__components__grp.html#ga21048d100cc51ab6d1f5e48189e10d0a":[1,0,1,3],
"group__PMP__keep__connected__components__grp.html#ga239704e9a2752ed67d361be55acf3bf9":[1,0,1,1],
"group__PMP__keep__connected__components__grp.html#ga510bdc621fa423d202b22ba82c20ca7b":[1,0,1,8],
"group__PMP__keep__connected__components__grp.html#ga7dd1414e9366fed26c1f12c12c376b39":[1,0,1,2],
"group__PMP__keep__connected__components__grp.html#gaa30dc31656db0f4d1cab5b2c977bf855":[1,0,1,6],
"group__PMP__keep__connected__components__grp.html#gac1f733c7e7735c3fcec1ca107e6962ec":[1,0,1,7],
"group__PMP__keep__connected__components__grp.html#gad08d3489808a6ec8382a9fba3d288f39":[1,0,1,4],
"group__PMP__keep__connected__components__grp.html#gad417b04f530806789515a25530547a36":[1,0,1,0],
"group__PMP__keep__connected__components__grp.html#gae3812da28af74bdf9602a70ae1f9c817":[1,0,1,5],
"group__PMP__locate__grp.html":[1,0,14],
"group__PMP__locate__grp.html#ga1be5d5de27953a11b593797d5224fefd":[1,0,14,6],
"group__PMP__locate__grp.html#ga23816d7cea5cba77e56363c5ebd17b6e":[1,0,14,23],
"group__PMP__locate__grp.html#ga32bd9c2a74c9e475340a7e761539b3e1":[1,0,14,21],
"group__PMP__locate__grp.html#ga34d601277f6003a751716e29eb830038":[1,0,14,14],
"group__PMP__locate__grp.html#ga35604eae6b378b8254a3f41f1a274b9e":[1,0,14,2],
"group__PMP__locate__grp.html#ga455a6b4f1edfd88358a1150c870691e9":[1,0,14,9],
"group__PMP__locate__grp.html#ga475c1e0acddee2198db30289fa331b1b":[1,0,14,7],
"group__PMP__locate__grp.html#ga59628d063d4bc22dd52142a365c2f274":[1,0,14,18],
"group__PMP__locate__grp.html#ga609d1fd3a16ecc381a1b131386fc708c":[1,0,14,20],
"group__PMP__locate__grp.html#ga6581d3f34a14d533fdab2e6beef2873f":[1,0,14,0],
"group__PMP__locate__grp.html#ga6d90010ec9ad9c07c3659d12d7453d74":[1,0,14,24],
"group__PMP__locate__grp.html#ga72808d7750dab4989b4613dfa1dd46fc":[1,0,14,3],
"group__PMP__locate__grp.html#ga7632ebc56378e6ded961eab21540cecb":[1,0,14,5],
"group__PMP__locate__grp.html#ga777f3083d65c79021429c9884a828682":[1,0,14,19],
"group__PMP__locate__grp.html#ga817d3417a9711b3efbfde45e46e0aa00":[1,0,14,13],
"group__PMP__locate__grp.html#ga8ec69004f1d28b296aa9e89926bb3981":[1,0,14,1],
"group__PMP__locate__grp.html#ga905f903215a1123afef50b74d5424bda":[1,0,14,11],
"group__PMP__locate__grp.html#ga90eb394aab0e2f1a78d5f69c87cdcb53":[1,0,14,12],
"group__PMP__locate__grp.html#gaa8b9a0579a35e7beff2ab54aa911cff1":[1,0,14,16],
"group__PMP__locate__grp.html#gac78863fa23c382d08f9944a4f70b7a75":[1,0,14,22],
"group__PMP__locate__grp.html#gad94f826508b2a7d47bffe1c9e9164fa2":[1,0,14,10],
"group__PMP__locate__grp.html#gae0f1a2098f3f8c86c3bca86926517f21":[1,0,14,15],
"group__PMP__locate__grp.html#gaea15285dfafaa66a11deede8fdba473e":[1,0,14,17],
"group__PMP__locate__grp.html#gaf90da1db1204afbf66dbebd17d2e3e27":[1,0,14,8],
"group__PMP__locate__grp.html#gafa64630e9a7b1cbc28875d63ac8a3eaa":[1,0,14,4],
"group__PMP__measure__grp.html":[1,0,6],
"group__PMP__measure__grp.html#ga03162f7ecf67254f318a230b6dad3653":[1,0,6,10],
"group__PMP__measure__grp.html#ga1190f04c4b91b33cbb13f4f429c50005":[1,0,6,11],
"group__PMP__measure__grp.html#ga28ad46d585ae505c6f6696b1af9b18ae":[1,0,6,4],
"group__PMP__measure__grp.html#ga36667883a2aea525e578f95100006ab5":[1,0,6,9],
"group__PMP__measure__grp.html#ga3cb8dd4133e21dc9f6db97d2f50cc3f0":[1,0,6,6],
"group__PMP__measure__grp.html#ga654cb1da1be38e141b6340bd33aaf66f":[1,0,6,8],
"group__PMP__measure__grp.html#ga8124de2121266ce57f9ad71de570cf5d":[1,0,6,1],
"group__PMP__measure__grp.html#ga90dc3dc18ae03b37e825f6b4b4ee2dd0":[1,0,6,7],
"group__PMP__measure__grp.html#gaaffc67e631d83a7da4b1096b782ead94":[1,0,6,3],
"group__PMP__measure__grp.html#gadcc6926cfa00708e48d006074ce69c22":[1,0,6,0],
"group__PMP__measure__grp.html#gae1b5dbd88bbd5b58517e685ee4e0172c":[1,0,6,2],
"group__PMP__measure__grp.html#gaf643adc62ed10ec185c67f611378ef77":[1,0,6,5],
"group__PMP__meshing__grp.html":[1,0,3],
"group__PMP__meshing__grp.html#ga047c58233b234917fd310e190103e0cd":[1,0,3,12],
"group__PMP__meshing__grp.html#ga0e6da479548199a5d82c3cf0ed36e8a0":[1,0,3,13],
"group__PMP__meshing__grp.html#ga136c659162e5360354db5879db7431b4":[1,0,3,18],
"group__PMP__meshing__grp.html#ga173007e56da9246f63f2730e30b87844":[1,0,3,16],
"group__PMP__meshing__grp.html#ga300c5eedd7d62bbd10ad2655405562f4":[1,0,3,6],
"group__PMP__meshing__grp.html#ga412f696ec3009074bf957f1bba638248":[1,0,3,9],
"group__PMP__meshing__grp.html#ga54559e61c73ce4481f4a3374a61ca038":[1,0,3,20],
"group__PMP__meshing__grp.html#ga57fa999abe8dc557003482444df2a189":[1,0,3,15],
"group__PMP__meshing__grp.html#ga626f12385ac7fb10125772c3786b4ea8":[1,0,3,22],
"group__PMP__meshing__grp.html#ga6e971b85a933e194198218130ba98c0b":[1,0,3,5],
"group__PMP__meshing__grp.html#ga7fca6fa2db94560ab6d32e6a77fc35b6":[1,0,3,14],
"group__PMP__meshing__grp.html#ga8a906fba78439b213e06dbd7ba510a05":[1,0,3,19],
"group__PMP__meshing__grp.html#ga8b7db6aa8c3e79526b594739ba926d82":[1,0,3,23],
"group__PMP__meshing__grp.html#ga8dd9fe24ba2faa55a1ca3eb75c4806ae":[1,0,3,10],
"group__PMP__meshing__grp.html#ga9988e9a2eaf92740b3009d06c792f2cd":[1,0,3,8],
"group__PMP__meshing__grp.html#gad5a9a90355bab0613d94a6b9d73d54ed":[1,0,3,4],
"group__PMP__meshing__grp.html#gae6be1cd5e76dcc3d6b63a0c55ae78999":[1,0,3,11],
"group__PMP__meshing__grp.html#gaf094a938993d7353589a55010edf63a6":[1,0,3,21],
"group__PMP__meshing__grp.html#gaf70b64f0ab2649785c14876a6ed328d6":[1,0,3,7],
"group__PMP__meshing__grp.html#gaff62f9415d2fe96d1d3095351f156ced":[1,0,3,17],
"group__PMP__normal__grp.html":[1,0,5],
"group__PMP__normal__grp.html#ga4224769cbbedf39c9e73cb4997744ebf":[1,0,5,2],
"group__PMP__normal__grp.html#ga74e6b247d7e28beb677076aad5614d8c":[1,0,5,4],
"group__PMP__normal__grp.html#ga8346b5625ca097a9938616d10079cec5":[1,0,5,3],
"group__PMP__normal__grp.html#ga8d98ee0b7fdfe2e3a0fad7ec18e2cb71":[1,0,5,0],
"group__PMP__normal__grp.html#ga99095686a49fe6a45c933dae6217beb5":[1,0,5,1],
"group__PMP__orientation__grp.html":[1,0,7],
"group__PMP__orientation__grp.html#ga0cc8819f7a6e09086a9381fa29918d48":[1,0,7,1],
"group__PMP__orientation__grp.html#ga10325d30c17096eed40938545b53cb14":[1,0,7,6],
"group__PMP__orientation__grp.html#ga21119757bf5835496ae1c9a6d4f5fa0a":[1,0,7,12],
"group__PMP__orientation__grp.html#ga2aa4f7b500dc51d1fc4747705a050946":[1,0,7,4],
"group__PMP__orientation__grp.html#ga2f504990a24f599c20cd57161f9755f0":[1,0,7,10],
"group__PMP__orientation__grp.html#ga2fab7b3c952c86de66de2fef9fe83d74":[1,0,7,3],
"group__PMP__orientation__grp.html#ga6e71985647e2705328a6df45b7961994":[1,0,7,7],
"group__PMP__orientation__grp.html#ga855b1c55c201b91ab04eebd2811a87fd":[1,0,7,11],
"group__PMP__orientation__grp.html#ga9ac9b9434084b64f3304df636c3178a3":[1,0,7,2],
"group__PMP__orientation__grp.html#gab43990ca5541b788c6db2ba509a73ee3":[1,0,7,14],
"group__PMP__orientation__grp.html#gabdb85ef9ccc1a4da632f1a697c6d5163":[1,0,7,5],
"group__PMP__orientation__grp.html#gad380465ee62d858d27fab4cfda6c1764":[1,0,7,8],
"group__PMP__orientation__grp.html#gad8a3439883e3e76651f96d15ba58b2bc":[1,0,7,13],
"group__PMP__orientation__grp.html#gadf6efc8f4475792ccafe36f3e8734302":[1,0,7,9],
"group__PMP__orientation__grp.html#gga0cc8819f7a6e09086a9381fa29918d48a421e502b1cb8f48d1f9f3e84a046c31d":[1,0,7,1,2],
"group__PMP__orientation__grp.html#gga0cc8819f7a6e09086a9381fa29918d48a7c11c1c20f8917e666b1fa936d0571f1":[1,0,7,1,3],
"group__PMP__orientation__grp.html#gga0cc8819f7a6e09086a9381fa29918d48ab0b5c051e298e25b83338c5e7b3a4704":[1,0,7,1,0],
"group__PMP__orientation__grp.html#gga0cc8819f7a6e09086a9381fa29918d48ad9e462d2dfe21137aa9dfb56e0a8d067":[1,0,7,1,1],
"group__PMP__predicates__grp.html":[1,0,15],
"group__PMP__predicates__grp.html#ga349da012e9a09a6085e2607c3e9ea9fb":[1,0,15,3],
"group__PMP__predicates__grp.html#ga3f58569399266bf51bc3156f310e6bd0":[1,0,15,6],
"group__PMP__predicates__grp.html#ga482e70b514067bb25403009e0a861262":[1,0,15,7],
"group__PMP__predicates__grp.html#ga4e1b0b968527ce2d0c2f903022b41db4":[1,0,15,8],
"group__PMP__predicates__grp.html#ga8792f19475d1b066ed9b9bf35d69c695":[1,0,15,1],
"group__PMP__predicates__grp.html#gaaaa700acb908e56b939b0279020ee06b":[1,0,15,2],
"group__PMP__predicates__grp.html#gad901eb3ea93d84417ffcd0da602be78f":[1,0,15,5],
"group__PMP__predicates__grp.html#gafd9ae763020a18b55902b88402c6537c":[1,0,15,4],
"group__PkgPolygonMeshProcessingConcepts.html":[1,0,0],
"group__PkgPolygonMeshProcessingRef.html":[1,0],
"group__PkgPolygonMeshProcessingRef.html#ga0542a44d0d081f84e387b1e6bcbca471":[1,0,32],
"group__PkgPolygonMeshProcessingRef.html#ga132e91e574d2454eb39f05a4e8e72099":[1,0,24],
"group__PkgPolygonMeshProcessingRef.html#ga396505d5a60b5f6d29792b214fa59352":[1,0,29],
"group__PkgPolygonMeshProcessingRef.html#ga42723af60dc8810d938490a8caceb7f0":[1,0,27],
"group__PkgPolygonMeshProcessingRef.html#ga50dcd2f6295f584d2e378b57290ae2af":[1,0,30],
"group__PkgPolygonMeshProcessingRef.html#ga5e3404d49ea27fba8e9594fbaf27662c":[1,0,33],
"group__PkgPolygonMeshProcessingRef.html#ga8df4cdc887edf1e20b4a13f29886c0e3":[1,0,26],
"group__PkgPolygonMeshProcessingRef.html#gabaf98d2fd9ae599ff1f3a5a6cde79cf3":[1,0,22],
"group__PkgPolygonMeshProcessingRef.html#gac8e445730d718a2fc49604e865017d2e":[1,0,25],
"group__PkgPolygonMeshProcessingRef.html#gae466d7641a473368e491a6c30584a5d9":[1,0,28],
"group__PkgPolygonMeshProcessingRef.html#gaf2cbaecebb112bc4857782728481ccec":[1,0,31],
"group__PkgPolygonMeshProcessingRef.html#gaf633ec6397f5f065b01462fe42235d56":[1,0,23],
"index.html":[],
"index.html":[0],
"index.html#AHDExample":[0,12,0,0],
"index.html#ApproxHD":[0,12,0],
"index.html#BHDExample":[0,12,1,0],
"index.html#BoundedHD":[0,12,1],
"index.html#CCExample":[0,11,0],
"index.html#Coref_section":[0,2],
"index.html#Decimate":[0,1,0,1,2],
"index.html#Delaunay-Based":[0,1,0,1,1],
"index.html#DetectFeaturesExample":[0,13,0],
"index.html#Extrusion":[0,1,0,3],
"index.html#ExtrusionExample":[0,1,1,3],
"index.html#FixNMVerticeExample":[0,6,2,0],
"index.html#HFExample_1":[0,3,1,0],
"index.html#HFExample_2":[0,3,1,1],
"index.html#HFExamples":[0,3,1],
"index.html#HFPerformance":[0,3,2],
"index.html#HoleFillingAPI":[0,3,0],
"index.html#ICCAPI":[0,9,1],
"index.html#ICCBackground":[0,9,0],
"index.html#ICCExamplePH":[0,9,5],
"index.html#ICCExampleSM":[0,9,4],
"index.html#ICCExampleSV":[0,9,6],
"index.html#ICCPerformance":[0,9,3],
"index.html#ICCResults":[0,9,2],
"index.html#InsideExample":[0,4,1,0],
"index.html#Local":[0,1,0,1,0],
"index.html#Meshing":[0,1,0,0],
"index.html#MeshingAPI":[0,1,0],
"index.html#MeshingExample_1":[0,1,1,0],
"index.html#MeshingExample_2":[0,1,1,1],
"index.html#MeshingExamples":[0,1,1],
"index.html#NormalsExample":[0,8,0],
"index.html#NormalsExampleP":[0,8,0,1],
"index.html#NormalsExampleSM":[0,8,0,0],
"index.html#OrientingPolygonMeshes":[0,5,1],
"index.html#PMPAPI":[0,0,1],
"index.html#PMPAutoref":[0,7,0],
"index.html#PMPCombinatorialRepair":[0,6],
"index.html#PMPConnectedComponents":[0,11],
"index.html#PMPDef":[0,0,0],
"index.html#PMPDetectFeatures":[0,13],
"index.html#PMPDistance":[0,12],
"index.html#PMPDoIntersect":[0,4,0],
"index.html#PMPDuplicateVertexBoundaryCycle":[0,6,3],
"index.html#PMPEnvelope":[0,4,2],
"index.html#PMPGeometricRepair":[0,7],
"index.html#PMPHistory":[0,14],
"index.html#PMPHoleFilling":[0,3],
"index.html#PMPICC":[0,9],
"index.html#PMPIO":[0,0,3],
"index.html#PMPInsideTest":[0,4,1],
"index.html#PMPIntroduction":[0,0],
"index.html#PMPLocationFunctions":[0,4,4],
"index.html#PMPManifoldness":[0,6,2],
"index.html#PMPMeshing":[0,1],
"index.html#PMPNormalComp":[0,8],
"index.html#PMPOrientation":[0,5],
"index.html#PMPOutline":[0,0,2],
"index.html#PMPPolygonSoups":[0,5,0],
"index.html#PMPPredicates":[0,4],
"index.html#PMPRemoveCapsNeedles":[0,7,1],
"index.html#PMPSelIntersections":[0,4,0,0],
"index.html#PMPShapePredicates":[0,4,3],
"index.html#PMPSlicer":[0,10],
"index.html#PSRepairing":[0,6,0],
"index.html#PoissonDistanceExample":[0,12,0,1],
"index.html#PolygonSoupExample":[0,5,2],
"index.html#PolyhedralEnvelopeExample":[0,4,2,0],
"index.html#Remeshing":[0,1,0,1],
"index.html#RemeshingExample_1":[0,1,1,2],
"index.html#SIExample":[0,4,0,1],
"index.html#SlicerExample":[0,10,0],
"index.html#Smoothing":[0,1,0,2],
"index.html#Stitching":[0,6,1],
"index.html#StitchingExample":[0,6,1,0],
"index.html#coref_bolop_subsec":[0,2,2],
"index.html#coref_clip":[0,2,4],
"index.html#coref_coref_subsec":[0,2,1],
"index.html#coref_def_subsec":[0,2,0],
"index.html#coref_ex_consq_subsec":[0,2,5,2],
"index.html#coref_ex_refine_subsec":[0,2,5,1],
"index.html#coref_ex_subsec":[0,2,5],
"index.html#coref_ex_union_subsec":[0,2,5,0],
"index.html#coref_valid_subsec":[0,2,3],
"modules.html":[1],
"pages.html":[],
"polygon__mesh__processing_8h.html":[1,0,18],
"structCGAL_1_1Polygon__mesh__processing_1_1Autorefinement_1_1Default__visitor.html":[1,0,12,0],
"structCGAL_1_1Polygon__mesh__processing_1_1Corefinement_1_1Default__visitor.html":[1,0,12,1],
"structCGAL_1_1Polygon__mesh__processing_1_1Corefinement_1_1Non__manifold__output__visitor.html":[1,0,12,2],
"structCGAL_1_1Polygon__mesh__processing_1_1Corefinement_1_1Non__manifold__output__visitor.html#a076e89303bcd655c2f06eb32c0e04f90":[1,0,12,2,3],
"structCGAL_1_1Polygon__mesh__processing_1_1Corefinement_1_1Non__manifold__output__visitor.html#aabfab73a7dd683cc714d7926d0515edc":[1,0,12,2,1],
"structCGAL_1_1Polygon__mesh__processing_1_1Corefinement_1_1Non__manifold__output__visitor.html#aae8d5a9622b2fe1c26e9b1842553bf49":[1,0,12,2,2],
"structCGAL_1_1Polygon__mesh__processing_1_1Corefinement_1_1Non__manifold__output__visitor.html#ac707152f7e66c013b76d2bcd4c76a722":[1,0,12,2,4],
"structCGAL_1_1Polygon__mesh__processing_1_1Corefinement_1_1Non__manifold__output__visitor.html#ae536f0592f4521fda89e568d9b05ecaa":[1,0,12,2,0],
"structCGAL_1_1Polygon__mesh__processing_1_1Default__orientation__visitor.html":[1,0,7,0],
"structCGAL_1_1Polygon__mesh__processing_1_1Hole__filling_1_1Default__visitor.html":[1,0,2,0],
"structCGAL_1_1Polygon__mesh__processing_1_1Principal__curvatures__and__directions.html":[1,0,4,0],
"structCGAL_1_1Polygon__mesh__processing_1_1Principal__curvatures__and__directions.html#a0646d6de154a6aabf154517dcd4b23cb":[1,0,4,0,1],
"structCGAL_1_1Polygon__mesh__processing_1_1Principal__curvatures__and__directions.html#a2aef5a24f431e5e33b3356a8bf2aa40f":[1,0,4,0,2],
"structCGAL_1_1Polygon__mesh__processing_1_1Principal__curvatures__and__directions.html#a5528119a31cd82f87b308ab0d36be6bb":[1,0,4,0,3],
"structCGAL_1_1Polygon__mesh__processing_1_1Principal__curvatures__and__directions.html#a92c77d4d5b17d2816bb3b714a4c1d0f5":[1,0,4,0,0],
"structCGAL_1_1Polygon__mesh__processing_1_1Triangulate__faces_1_1Default__visitor.html":[1,0,3,2],
"structCGAL_1_1Polygon__mesh__processing_1_1Triangulate__polygons_1_1Default__visitor.html":[1,0,3,3],
"structCGAL_1_1Polyhedral__envelope.html":[1,0,20],
"structCGAL_1_1Polyhedral__envelope.html#a1ecff8afd71b42e8757fa2e24d1d4555":[1,0,20,1],
"structCGAL_1_1Polyhedral__envelope.html#a235323a9a43dbc8a03720c7e7758d649":[1,0,20,7]
};
